---
title: Athena
sub_title: Your AI cyber security advisor
action_link: athena
action_text: Go
---

[Athena](athena) takes her name from the Greek goddess of wisdom, courage and strategic warfare. Her mission is
to help you with any questions you might have on cyber security.
               
Athena’s extensive training will provide you with information, strategic guidance and advice on the
cyber security risks your organisation faces.
